/* eslint-disable no-unused-vars */
/* eslint-disable @typescript-eslint/no-unused-vars */
import express, { Application, NextFunction, Request, Response } from 'express'
import cors from 'cors'
import httpStatus from 'http-status'
import middlewareRouter from './app/routes'
import globalErrorHandler from './app/middleware/globalErrorHandler'
import cookieParser from 'cookie-parser'

const app: Application = express()
app.use(express.json())
app.use(
  cors({
    origin: ['https://infinityhubbd.online', 'http://localhost:5173'],
    credentials: true,
  }),
)
app.use(express.urlencoded({ extended: true }))
app.use(cookieParser())
app.options('*', cors())

app.use('/api/v1', middlewareRouter)

app.get('/', (req: Request, res: Response) => {
  res.status(httpStatus.OK).json({
    status: httpStatus.OK,
    success: true,
    message: 'E-ticketing server is running',
  })
})

app.use(globalErrorHandler)

app.use((req: Request, res: Response, next: NextFunction) => {
  res.status(404).json({
    success: false,
    message: 'Api not found',
    error: {
      path: req.originalUrl,
      message: 'Your requested path is not found',
    },
  })
})

export default app
