/* eslint-disable no-unused-vars */
/* eslint-disable @typescript-eslint/no-unused-vars */
import { NextFunction, Request, Response } from 'express'
import jwt, { JwtPayload } from 'jsonwebtoken'
import config from '../config'
import { prisma } from '../shared/prisma'
import { UserStatus } from '@prisma/client'
import ApiError from '../error/ApiError'
import httpStatus from 'http-status'

const auth = (...roles: string[]) => {
  return async (req: Request, res: Response, next: NextFunction) => {
    try {
      const token = req.headers.authorization

      if (!token) {
        throw new ApiError(httpStatus.UNAUTHORIZED, 'You are not authorized ')
      }

      //token expire hye gele error showing er jonno try catch is used here
      let decoded
      try {
        decoded = jwt.verify(
          token,
          config.access_token_sceret as string,
        ) as JwtPayload
      } catch (error) {
        throw new ApiError(httpStatus.UNAUTHORIZED, 'You are not authorized ')
      }

      if (roles.length && !roles.includes(decoded?.role)) {
        throw new ApiError(httpStatus.UNAUTHORIZED, ' You are not authorized ')
      }

      const { contactNumber } = decoded

      const user = await prisma.user.findUnique({
        where: {
          contactNumber,
        },
      })

      if (!user) {
        throw new ApiError(httpStatus.UNAUTHORIZED, 'User not found')
      }

      if (user?.status === UserStatus.BLOCKED || user?.isDeleted === true) {
        throw new ApiError(httpStatus.UNAUTHORIZED, 'You are not authorized ')
      }

      req.user = decoded
      next()
    } catch (ApiError) {
      next(ApiError)
    }
  }
}

export default auth
