import catchAsync from '../../shared/catchAsync'
import pick from '../../shared/pick'
import sendResponse from '../../shared/sendResponse'
import { airLinesSearchAbleField, peginationField } from './airLines.constant'
import { AirService } from './airLines.service'
import httpStatus from 'http-status'

const createAir = catchAsync(async (req, res) => {
  const result = await AirService.createAirIntoDB(req.body)
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Air created successfully',
    data: result,
  })
})

const getAirLines = catchAsync(async (req, res) => {
  const filterData = pick(req.query, airLinesSearchAbleField)
  const paginationData = pick(req.query, peginationField)
  const result = await AirService.getAirLinesIntoDB(filterData, paginationData)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Air lines fetched successfully',
    meta: result.meta,
    data: result.data,
  })
})

const getAirLinesById = catchAsync(async (req, res) => {
  const { id } = req.params

  const result = await AirService.getAirLinesByIdIntoDB(id)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Air lines fetched successfully',
    data: result,
  })
})

const updateAirLinesInfo = catchAsync(async (req, res) => {
  const { id } = req.params
  const airLinesData = req.body
  const result = await AirService.updateAirLinesInfoIntoDB(id, airLinesData)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Air lines updated successfully',
    data: result,
  })
})

const deleteAirLines = catchAsync(async (req, res) => {
  const { id } = req.params
  const result = await AirService.softDeleteAirLinesIntoDB(id)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Air lines deleted successfully',
    data: result,
  })
})

export const AirController = {
  createAir,
  getAirLines,
  getAirLinesById,
  updateAirLinesInfo,
  deleteAirLines,
}
