import z from 'zod'

const createAirLinesSchemaValidation = z.object({
  airLinesName: z.string({
    required_error: 'Airline name is required',
  }),
  email: z.string().email({ message: 'Invalid email address' }),
  contactNumber: z.string({
    required_error: 'Contact number is required',
  }),
  emergencyContactNumber: z.string({
    required_error: 'Emergency contact number is required',
  }),
  logo: z.string().url().optional(),
  address: z.string({
    required_error: 'Address is required',
  }),
  planeQuantity: z.number({
    required_error: 'Plane quantity is required',
  }),
})

const updateAirLinesSchemaValidation = z.object({
  body: z.object({
    airLinesName: z.string().optional(),
    email: z.string().email().optional(),
    contactNumber: z.string().optional(),
    emergencyContactNumber: z.string().optional(),
    logo: z.string().url().optional(),
    address: z.string().optional(),
    planeQuantity: z.number().optional(),
  }),
})

export const AirLinesValidation = {
  createAirLinesSchemaValidation,
  updateAirLinesSchemaValidation,
}
