import { AirPort } from '@prisma/client'
import { prisma } from '../../shared/prisma'
import { TParams } from '../airLines/airLines.interface'

const createAirportIntoDB = async (payload: AirPort) => {
  // const isAirportExist = await prisma.airPort.findUnique({
  //   where: {
  //     airPortName: payload.airPortName,
  //   },
  // })

  // if (isAirportExist) {
  //   throw new ApiError(httpStatus.FORBIDDEN, 'Airport already exist')
  // }

  const result = await prisma.airPort.createMany({
    data: payload,
  })
  return result
}

const getAirportsFromDB = async (params: TParams) => {
  const andCondition = []

  const searchAbleField = ['city', 'country', 'airPortName']

  if (params.searchTerm) {
    const orConditions = []

    // Apply startsWith when the search term is exactly 1 character
    if (params.searchTerm.length === 1) {
      orConditions.push({
        [searchAbleField[0]]: {
          startsWith: params.searchTerm,
          mode: 'insensitive',
        },
      })
    }

    // Apply contains when the search term is longer than 1 character
    if (params.searchTerm.length >= 1) {
      searchAbleField.forEach(field => {
        orConditions.push({
          [field]: {
            contains: params.searchTerm,
            mode: 'insensitive',
          },
        })
      })
    }

    // Apply equals for an exact match
    orConditions.push({
      [searchAbleField[0]]: {
        equals: params.searchTerm,
        mode: 'insensitive',
      },
    })

    // Only add the OR condition if we have any valid OR conditions
    if (orConditions.length > 0) {
      andCondition.push({
        OR: orConditions,
      })
    }
  }

  const whereCondition = andCondition.length > 0 ? { AND: andCondition } : {}

  const result = await prisma.airPort.findMany({
    where: whereCondition,
    select: {
      airPortName: true,
      airportCode: true,
      city: true,
      country: true,
    },
  })

  return result
}

export const AirportService = {
  createAirportIntoDB,
  getAirportsFromDB,
}
