import catchAsync from '../../shared/catchAsync'
import sendResponse from '../../shared/sendResponse'
import { AuthService } from './auth.service'
import httpStatus from 'http-status'

const registerUser = catchAsync(async (req, res) => {
  const result = await AuthService.register(req.body)
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Account Created successfully',
    data: result,
  })
})

const authLogin = catchAsync(async (req, res) => {
  const result = await AuthService.login(req.body)
  const { accessToken, refreshToken } = result

  res.cookie('refresh', refreshToken, {
    httpOnly: true,
    secure: true,
    sameSite: 'none',
    domain: 'infinityhubbd.online',
  })
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Login successfully',
    data: { accessToken },
  })
})

const refreshToken = catchAsync(async (req, res) => {
  const { refresh } = req.cookies
  const result = await AuthService.createRefreshToken(refresh)
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Access token generated  successfully',
    data: { accessToken: result },
  })
})

//forger password
const forgetPasswordForReset = catchAsync(async (req, res) => {
  const result = await AuthService.forgetPassword(req.body)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Password reset link sent to your email',
    data: result,
  })
})

//reset password
const resetPassword = catchAsync(async (req, res) => {
  const token = req.headers.authorization
  const result = await AuthService.resetPasswordInto(token as string, req.body)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Password reset successfully',
    data: result,
  })
})

export const AuthController = {
  authLogin,
  registerUser,
  refreshToken,
  forgetPasswordForReset,
  resetPassword,
}
