import z from 'zod'

const authSchemaValidation = z.object({
  body: z.object({
    contactNumber: z.string({
      required_error: 'Contact number is required',
    }),
    password: z.string({
      required_error: 'Password is required',
    }),
  }),
})

const registerSchemaValidation = z.object({
  body: z.object({
    fullName: z.string({
      required_error: 'Full name is required',
    }),
    email: z
      .string({
        required_error: 'Email is required',
      })
      .email(),
    contactNumber: z.string({
      required_error: 'Contact number is required',
    }),
    emergencyContactNumber: z.string({
      required_error: 'Emergency contact number is required',
    }),
    gender: z.enum(['MALE', 'FEMALE'], {
      required_error: 'Gender is required',
    }),
    dateOfBirth: z.string({
      required_error: 'Date of birth is required',
    }),
    password: z.string({
      required_error: 'Password is required',
    }),
  }),
})

export const AuthValidation = {
  authSchemaValidation,
  registerSchemaValidation,
}
