import { Request } from 'express'
import { prisma } from '../../../shared/prisma'

const createBusCounterIntoDB = async (req: Request) => {
  const { contactNumber } = req.user

  const payload = req.body

  const findCompany = await prisma.busCompanyOwner.findUnique({
    where: {
      contactNumber: contactNumber,
    },
    include: {
      busCompany: {
        select: {
          id: true,
          companyName: true,
        },
      },
    },
  })

  if (!findCompany) {
    throw new Error('Company owner not found')
  }

  const busCounterData = {
    busCompanyId: findCompany?.busCompany?.id,
    ...payload,
  }

  const result = await prisma.busCounter.create({
    data: busCounterData,
  })

  return result
}

const getAllBusCounterFromDB = async (req: Request) => {
  const { contactNumber } = req.user

  const findCompany = await prisma.busCompanyOwner.findUnique({
    where: {
      contactNumber: contactNumber,
    },
    include: {
      busCompany: {
        include: {
          busCounter: true,
        },
      },
    },
  })

  const result = await prisma.busCounter.findMany({
    where: {
      busCompanyId: findCompany?.busCompany?.id,
    },
    include: {
      busCompany: {
        select: {
          id: true,
          companyName: true,
        },
      },
    },
  })
  return result
}

export const BusCounterService = {
  createBusCounterIntoDB,
  getAllBusCounterFromDB,
}
