import catchAsync from '../../../shared/catchAsync'
import { BusDetailsService } from './busDetails.service'
import httpStatus from 'http-status'

const createBusDetails = catchAsync(async (req, res) => {
  const result = await BusDetailsService.createBusDetailsIntoDB(req)
  res.status(201).json({
    statusCode: httpStatus.CREATED,
    message: 'Bus details created successfully',
    data: result,
  })
})

const getBusDetails = catchAsync(async (req, res) => {
  const { id } = req.query
  const result = await BusDetailsService.getAllBusFromDB(req, id as string)
  res.status(201).json({
    statusCode: httpStatus.OK,
    message: 'Bus details fetch successfully',
    data: result,
  })
})

const getSpicificBusDetails = catchAsync(async (req, res) => {
  const id = req.params.id
  const result = await BusDetailsService.getSpicificBusDetails(id)
  res.status(200).json({
    statusCode: httpStatus.OK,
    message: 'Bus details fetch successfully',
    data: result,
  })
})

const getBusForSearch = catchAsync(async (req, res) => {
  const query = req.query

  const result = await BusDetailsService.getAllBusForSearch(query)
  res.status(200).json({
    statusCode: httpStatus.OK,
    message: 'Bus details fetch successfully',
    data: result,
  })
})

const getAllBusFromDB = catchAsync(async (req, res) => {
  const result = await BusDetailsService.getAllBusForSuperAdmin()
  res.status(200).json({
    statusCode: httpStatus.OK,
    message: 'Bus details fetch successfully',
    data: result,
  })
})

export const BusDetailsController = {
  createBusDetails,
  getBusDetails,
  getSpicificBusDetails,
  getBusForSearch,
  getAllBusFromDB,
}
