import catchAsync from '../../../shared/catchAsync'
import { BusScheduleService } from './busSchedule.service'
import httpStatus from 'http-status'

const createBusSchedule = catchAsync(async (req, res) => {
  const result = await BusScheduleService.createBusScheduleIntoDB(req)
  res.status(201).json({
    statusCode: httpStatus.CREATED,
    message: 'Bus Schedule created successfully',
    data: result,
  })
})

const getBusSchedule = catchAsync(async (req, res) => {
  const result = await BusScheduleService.getAllBusScheduleIntoDB(req.query)
  res.status(201).json({
    statusCode: httpStatus.OK,
    message: 'Bus Schedule fetch successfully',
    data: result,
  })
})

const getBusSchedules = catchAsync(async (req, res) => {
  const result = await BusScheduleService.getAllBusScheduleFromDB(req)
  res.status(201).json({
    statusCode: httpStatus.OK,
    message: 'Bus Schedule fetch successfully',
    data: result,
  })
})

const runningTodayBusFromDB = catchAsync(async (req, res) => {
  const result = await BusScheduleService.runningTodayBus()
  res.status(201).json({
    statusCode: httpStatus.OK,
    message: 'Bus Schedule fetch successfully',
    data: result,
  })
})

const updateTicketPrice = catchAsync(async (req, res) => {
  const { id } = req.params

  const result = await BusScheduleService.priceUpdateForSpicificSchedule(
    id,
    req.body,
  )
  res.status(201).json({
    statusCode: httpStatus.OK,
    message: 'Bus Schedule updated successfully',
    data: result,
  })
})

export const BusScheduleController = {
  createBusSchedule,
  getBusSchedule,
  getBusSchedules,
  runningTodayBusFromDB,
  updateTicketPrice,
}
