/* eslint-disable no-console */
/* eslint-disable @typescript-eslint/no-explicit-any */
import { Request } from 'express'
import { prisma } from '../../../shared/prisma'
import { addDays, format } from 'date-fns'
import { BusSchedule } from '@prisma/client'

//create schedule for bus
const createBusScheduleIntoDB = async (req: Request) => {
  const {
    busId,
    departureDate,
    startPoint,
    endPoint,
    ticketPrice,
    departureTimeForward,
    arrivalTimeForward,
    departureTimeBackward,
    arrivalTimeBackward,
  } = req.body

  const startDate = new Date(departureDate.trim())

  const endDate = addDays(startDate, 30)

  const forwardDays = [5, 0, 2, 4]
  const backwardDays = [1, 3, 6]

  let currentDate = startDate
  const routeSchedules: any = []

  const forwardDirection = 'forward'
  const backwardDirection = 'backward'

  // Generate the schedule
  while (currentDate <= endDate) {
    const dayOfWeek = currentDate.getDay()

    if (forwardDays.includes(dayOfWeek)) {
      routeSchedules.push({
        busId,
        departureDate: format(currentDate, 'yyyy-MM-dd'),
        direction: forwardDirection,
        startPoint: forwardDirection === 'forward' && startPoint,
        endPoint: forwardDirection === 'forward' && endPoint,
        departTime: departureTimeForward,
        arrivalTime: arrivalTimeForward,
        ticketPrice,
      })
    } else if (backwardDays.includes(dayOfWeek)) {
      routeSchedules.push({
        busId,
        departureDate: format(currentDate, 'yyyy-MM-dd'),
        direction: 'backward',
        startPoint: backwardDirection === 'backward' && endPoint,
        endPoint: backwardDirection === 'backward' && startPoint,
        departTime: departureTimeBackward,
        arrivalTime: arrivalTimeBackward,
        ticketPrice,
      })
    }

    currentDate = addDays(currentDate, 1)
  }

  const result = await prisma.busSchedule.createMany({
    data: routeSchedules,
  })

  return result
}

const getAllBusScheduleFromDB = async (req: Request) => {
  const { busId, startMonth, endMonth } = req.query as {
    busId: string
    startMonth: string
    endMonth: string
  }

  const findBus = await prisma.busDetails.findFirst({
    where: {
      id: busId,
    },
  })

  if (!findBus) {
    throw new Error('Bus not found')
  }

  const result = await prisma.busSchedule.findMany({
    where: {
      busId: busId,
      AND: [
        {
          departureDate: {
            gte: startMonth,
            lte: endMonth,
          },
        },
      ],
    },
  })

  return result
}

const runningTodayBus = async () => {
  const dateForRunning = new Date()
  const formatDate = format(dateForRunning, 'yyyy-MM-dd')

  const result = await prisma.busSchedule.findMany({
    where: {
      departureDate: formatDate,
    },
    include: {
      busDetails: true,
    },
  })

  return result
}

const getAllBusScheduleIntoDB = async (params: any) => {
  console.log(params)
}

//price update for spicific schedule
const priceUpdateForSpicificSchedule = async (
  id: string,
  payload: Partial<BusSchedule>,
) => {
  const result = await prisma.busSchedule.updateMany({
    where: {
      id: id,
    },
    data: {
      ...payload,
    },
  })

  return result
}

export const BusScheduleService = {
  createBusScheduleIntoDB,
  getAllBusScheduleIntoDB,
  getAllBusScheduleFromDB,
  runningTodayBus,
  priceUpdateForSpicificSchedule,
}
