/* eslint-disable @typescript-eslint/no-explicit-any */
import { BusStop } from '@prisma/client'
import { prisma } from '../../../shared/prisma'

const createBusStopIntoDB = async (payload: BusStop) => {
  const result = await prisma.busStop.createMany({
    data: payload,
  })
  return result
}

const getBusStopFromDB = async (params: any) => {
  const andCondition = []

  const searchAbleField = ['busStoppageLocation']
  if (params.searchTerm) {
    const orConditions = []

    // Apply startsWith when the search term is exactly 1 character
    if (params.searchTerm.length === 1) {
      orConditions.push({
        [searchAbleField[0]]: {
          startsWith: params.searchTerm,
          mode: 'insensitive',
        },
      })
    }

    // Apply contains when the search term is longer than 1 character
    if (params.searchTerm.length >= 1) {
      searchAbleField.forEach(field => {
        orConditions.push({
          [field]: {
            contains: params.searchTerm,
            mode: 'insensitive',
          },
        })
      })
    }

    // Apply equals for an exact match
    searchAbleField.forEach(field => {
      orConditions.push({
        [field]: {
          equals: params.searchTerm,
          mode: 'insensitive',
        },
      })
    })

    if (orConditions.length > 0) {
      andCondition.push({
        OR: orConditions,
      })
    }
  }

  const whereCondition = andCondition.length > 0 ? { AND: andCondition } : {}

  const result = await prisma.busStop.findMany({
    where: whereCondition,
    select: {
      id: true,
      busStoppageLocation: true,
    },
  })
  return result
}

export const BusStopService = {
  createBusStopIntoDB,
  getBusStopFromDB,
}
