import catchAsync from '../../../shared/catchAsync'
import sendResponse from '../../../shared/sendResponse'
import { BusTicketBookService } from './busTicketBook.service'
import httpStatus from 'http-status'

const createBusTicketBooking = catchAsync(async (req, res) => {
  const result = await BusTicketBookService.createBusTicketBookIntoDB(req.body)

  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Bus ticket created successfully',
    data: result,
  })
})

const getSeatBlockFromDB = catchAsync(async (req, res) => {
  const result = await BusTicketBookService.getSeatBlock(req)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Seat block fetched successfully',
    data: result,
  })
})

const passengerInfoInDB = catchAsync(async (req, res) => {
  const result = await BusTicketBookService.createBusTicketInfoForPassengerDB(
    req.body,
  )
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Passenger info created successfully',
    data: result,
  })
})

const getBusTicketForPassenger = catchAsync(async (req, res) => {
  const result = await BusTicketBookService.getTicketForSeparatePassenger(req)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Bus ticket for passenger fetched successfully',
    data: result,
  })
})

export const BusTicketController = {
  createBusTicketBooking,
  getSeatBlockFromDB,
  passengerInfoInDB,
  getBusTicketForPassenger,
}
