import { PassengerInfoForBus, SeatSelect } from '@prisma/client'
import { prisma } from '../../../shared/prisma'
import { Request } from 'express'

const createBusTicketBookIntoDB = async (payload: SeatSelect) => {
  const findSeat = await prisma.seatSelect.findFirst({
    where: {
      busId: payload.busId,
    },
  })

  if (findSeat && findSeat.seatNumber.length > 0) {
    const updatedField = payload.seatNumber.reduce((acc, seat) => {
      if (findSeat.seatNumber.includes(seat)) {
        return acc.filter(s => s !== seat)
      } else {
        return [...acc, seat]
      }
    }, findSeat.seatNumber)

    const result = await prisma.seatSelect.update({
      where: {
        id: findSeat.id,
      },
      data: {
        seatNumber: updatedField,
      },
    })

    return result
  }

  // If no seat selection exists, create a new entry
  const result = await prisma.seatSelect.create({ data: payload })
  return result
}

const getSeatBlock = async (req: Request) => {
  const id = req.params.id
  const result = await prisma.seatSelect.findMany({
    where: {
      busId: id,
    },
  })
  return result
}

const createBusTicketInfoForPassengerDB = async (
  payload: PassengerInfoForBus,
) => {
  const result = await prisma.passengerInfoForBus.create({ data: payload })
  return result
}

const getTicketForSeparatePassenger = async (req: Request) => {
  const id = req.params.id
  const result = await prisma.passengerInfoForBus.findFirst({
    where: {
      contactNumber: id,
    },
    include: {
      busDetails: {
        select: {
          busName: true,
          busCompany: true,
        },
      },
    },
  })
  return result
}

export const BusTicketBookService = {
  createBusTicketBookIntoDB,
  getSeatBlock,
  createBusTicketInfoForPassengerDB,
  getTicketForSeparatePassenger,
}
