import { Request } from 'express'
import { prisma } from '../../../shared/prisma'

const createCancelRequest = async (req: Request) => {
  const cancelData = req.body
  const { ticketNumber, customerId, ...rest } = cancelData

  if (
    !ticketNumber ||
    !Array.isArray(ticketNumber) ||
    ticketNumber.length === 0
  ) {
    throw new Error('ticketNumber must be a non-empty array')
  }

  if (!customerId) {
    throw new Error('customerId is required')
  }

  // Check if a record exists for the customer
  const existingRecord = await prisma.cancelTicket.findFirst({
    where: {
      customerId: customerId,
    },
  })

  let result

  if (existingRecord) {
    // Update the ticketNumber for the existing customer
    result = await prisma.cancelTicket.update({
      where: {
        id: existingRecord.id,
      },
      data: {
        ticketNumber: {
          push: ticketNumber,
        },
      },
    })
  } else {
    // Create a new record if the customer does not exist
    result = await prisma.cancelTicket.create({
      data: {
        ...rest,
        customerId,
        ticketNumber,
      },
    })
  }

  return result
}

const getCancelRequest = async (req: Request) => {
  const { contactNumber, role } = req.user

  let result

  if (role === 'PASSENGER') {
    result = await prisma.cancelTicket.findFirst({
      where: {
        passengerInfoForBus: {
          contactNumber,
        },
      },
    })
  } else {
    result = await prisma.cancelTicket.findMany({
      include: {
        passengerInfoForBus: true,
      },
    })
  }

  return result
}

export const CancelRequestService = {
  createCancelRequest,
  getCancelRequest,
}
