/* eslint-disable @typescript-eslint/no-explicit-any */
import { Coupon } from '@prisma/client'
import { prisma } from '../../../shared/prisma'
import { Request } from 'express'
import ApiError from '../../../error/ApiError'
import httpStatus from 'http-status'

const createCouponIntoDB = async (payload: Coupon) => {
  const result = await prisma.coupon.create({
    data: payload,
  })

  return result
}

// Get all coupons
const getAllCoupons = async () => {
  return await prisma.coupon.findMany()
}

// Update a coupon
const updateCoupon = async (req: Request) => {
  const id = req.params.id
  const payload = req.body

  const dataToUpdate: Record<string, any> = {}

  if (payload.percentage !== undefined && payload.percentage !== '') {
    dataToUpdate.percentage = parseInt(payload.percentage)
  }
  if (payload.endDate) {
    dataToUpdate.endDate = payload.endDate
  }
  if (payload.status) {
    dataToUpdate.status = payload.status
  }

  if (Object.keys(dataToUpdate).length === 0) {
    throw new ApiError(httpStatus.BAD_REQUEST, 'No fields to update.')
  }

  // Update using Prisma
  return await prisma.coupon.update({
    where: { id: id },
    data: dataToUpdate,
  })
}

export const CouponService = {
  createCouponIntoDB,
  getAllCoupons,
  updateCoupon,
}
