import { prisma } from '../../shared/prisma'
import ApiError from '../../error/ApiError'
import httpStatus from 'http-status'
import { Request } from 'express'

const createCompanyIntoDB = async (req: Request) => {
  const { contactNumber } = req.user
  const file = req.file
  const payload = req.body

  const findCompanyOwner = await prisma.busCompanyOwner.findUnique({
    where: {
      contactNumber: contactNumber,
    },
  })

  if (!findCompanyOwner) {
    throw new ApiError(httpStatus.FORBIDDEN, 'Company owner not found')
  }

  const isComapnyExist = await prisma.busCompany.findUnique({
    where: {
      companyName: payload.companyName,
    },
  })

  if (isComapnyExist) {
    throw new ApiError(httpStatus.FORBIDDEN, 'Company already exist')
  }

  const comapnyData = {
    busOwnerName: findCompanyOwner.id,
    companyName: payload.companyName,
    email: payload.email,
    contactNumber: payload.contactNumber,
    emergencyContactNumber: payload.emergencyContactNumber,
    logo: file?.path,
    address: payload.address,
    busQuantity: payload.busQuantity,
  }

  const result = await prisma.busCompany.create({
    data: comapnyData,
  })

  return result
}

const getAllBusCompanyIntoDB = async () => {
  const result = await prisma.busCompany.findMany({})
  return result
}

export const CompanyService = {
  createCompanyIntoDB,
  getAllBusCompanyIntoDB,
}
