import catchAsync from '../../shared/catchAsync'
import sendResponse from '../../shared/sendResponse'
import { FlightService } from './flight.service'
import httpStatus from 'http-status'

const createFlight = catchAsync(async (req, res) => {
  const result = await FlightService.createFlightIntoDB(req.body)
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Flight created successfully',
    data: result,
  })
})

const getFlights = catchAsync(async (req, res) => {
  const result = await FlightService.getFlightFromDB(req.query)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Flights fetched successfully',
    data: result,
  })
})

const getSingleFlights = catchAsync(async (req, res) => {
  const { outGoingFlighId, returnFlighId } = req.query // Adjusted to accept query parameters
  const result = await FlightService.getSingleFlightFromDB(
    outGoingFlighId as string,
    (returnFlighId as string) || undefined,
  )
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Flight data fetched successfully',
    data: result,
  })
})

export const FlightController = {
  createFlight,
  getFlights,
  getSingleFlights,
}
