/* eslint-disable no-unused-vars */
/* eslint-disable @typescript-eslint/no-unused-vars */
export type Weekday =
  | 'Monday'
  | 'Tuesday'
  | 'Wednesday'
  | 'Thursday'
  | 'Friday'
  | 'Saturday'
  | 'Sunday'

const DAYS_OF_WEEK = {
  Sunday: 0,
  Monday: 1,
  Tuesday: 2,
  Wednesday: 3,
  Thursday: 4,
  Friday: 5,
  Saturday: 6,
}

const generateDates = (weekArray: Weekday[], startDate: Date): Date[] => {
  const generatedDates: Date[] = []
  const today = new Date()
  const year = today.getFullYear()

  // Loop for the next 52 weeks (1 year)
  for (let week = 0; week < 52; week++) {
    weekArray.forEach(day => {
      const targetDay = DAYS_OF_WEEK[day]
      const currentDate = new Date(year, 0, 1 + week * 7) // Get the starting date for each week
      const dayOfWeek = currentDate.getDay()
      const daysUntilTarget = (targetDay - dayOfWeek + 7) % 7

      const date = new Date(currentDate)
      date.setDate(currentDate.getDate() + daysUntilTarget)

      if (date >= today) {
        generatedDates.push(date)
      }
    })
  }

  return generatedDates
}

// Generate Journey Dates based on the weekday array
export const generateJourneyDates = (weeksOfJourneyDay: Weekday[]): Date[] => {
  const startDate = new Date() // Current date to avoid generating past dates
  return generateDates(weeksOfJourneyDay, startDate)
}

// Calculate the duration between two times
export const calculateDuration = (
  departureTime: string,
  arrivalTime: string,
): string => {
  // Parse the time strings into hours and minutes
  const [departureHours, departureMinutes] = departureTime
    .split(':')
    .map(Number)
  const [arrivalHours, arrivalMinutes] = arrivalTime.split(':').map(Number)

  // Convert the times into total minutes since midnight
  const departureTotalMinutes = departureHours * 60 + departureMinutes
  const arrivalTotalMinutes = arrivalHours * 60 + arrivalMinutes

  // Calculate the duration in minutes
  let totalMinutes = arrivalTotalMinutes - departureTotalMinutes

  // Handle cases where the arrival time is on the next day
  if (totalMinutes < 0) {
    totalMinutes += 24 * 60 // Add 24 hours worth of minutes
  }

  // Calculate hours and minutes
  const hours = Math.floor(totalMinutes / 60)
  const minutes = totalMinutes % 60

  // Format the result
  if (hours > 0 && minutes > 0) return `${hours}h ${minutes}m` // Both hours and minutes exist
  if (hours > 0) return `${hours}h` // Only hours exist
  return `${minutes}m` // Only minutes exist
}
