import { Schedule } from '@prisma/client'
import { prisma } from '../../shared/prisma'
import {
  calculateDuration,
  generateJourneyDates,
  Weekday,
} from './ScheduleUtility'
import ApiError from '../../error/ApiError'
import httpStatus from 'http-status'

const createFlightScheduleIntoDB = async (payload: Schedule) => {
  const isFlightExist = await prisma.flight.findUnique({
    where: {
      id: payload.flightId,
    },
  })

  if (!isFlightExist) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Flight not found')
  }

  const isFlightScheduleExist = await prisma.schedule.findUnique({
    where: {
      id: payload.flightId,
    },
  })
  if (isFlightScheduleExist) {
    throw new ApiError(
      httpStatus.BAD_REQUEST,
      'This flight schedule has already created',
    )
  }

  // Calculate and format the duration
  const duration = calculateDuration(payload.departureTime, payload.arrivalTime)

  if (duration === 'Invalid duration') {
    throw new Error('Invalid departure and arrival times')
  }

  // Generate journeyDates using the provided weeksOfJourneyDay
  const journeyDates = generateJourneyDates(
    payload.weeksOfJourneyDay as Weekday[],
  )

  const result = await prisma.schedule.create({
    data: {
      flightId: payload.flightId,
      departureTime: payload.departureTime,
      arrivalTime: payload.arrivalTime,
      duration: duration,
      weeksOfJourneyDay: payload.weeksOfJourneyDay,
      journeyDates: journeyDates,
    },
  })

  return result
}

const getAllFlightScheduleFormDB = async () => {
  const result = await prisma.schedule.findMany({
    include: {
      flight: true,
    },
  })
  return result
}

export const FlightScheduleService = {
  createFlightScheduleIntoDB,
  getAllFlightScheduleFormDB,
}
