import { NextFunction, Request, Response, Router } from 'express'
import { PassengerController } from './passenger.controller'
import auth from '../../middleware/auth'
import { UserRoles } from '@prisma/client'
import { multerUploads } from '../../config/multer.config'

const router = Router()

router.get(
  '/get-passenger/:contactNumber',
  auth(UserRoles.SUPER_ADMIN, UserRoles.OWNER, UserRoles.PASSENGER),
  PassengerController.getPassengerFromDB,
)

router.get(
  '/me/all-tickets',
  auth(UserRoles.SUPER_ADMIN, UserRoles.OWNER, UserRoles.PASSENGER),
  PassengerController.getPassengerTicketForBus,
)

router.get(
  '/ticket-calculated',
  auth(UserRoles.SUPER_ADMIN, UserRoles.OWNER, UserRoles.PASSENGER),
  PassengerController.calculatingTicketForPassenger,
)

router.patch(
  '/update-passenger',
  auth(UserRoles.SUPER_ADMIN, UserRoles.OWNER, UserRoles.PASSENGER),
  multerUploads.single('image'),
  (req: Request, res: Response, next: NextFunction) => {
    req.body = JSON.parse(req.body.data)

    return PassengerController.updatePassengerInfoInDB(req, res, next)
  },
)

export const PassengerRoutes = router
