import catchAsync from '../../shared/catchAsync'
import pick from '../../shared/pick'
import sendResponse from '../../shared/sendResponse'
import { PlaneService } from './plane.service'
import httpStatus from 'http-status'

const createPlane = catchAsync(async (req, res) => {
  const result = await PlaneService.createPlaneIntoDB(req.body)
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Plane created successfully',
    data: result,
  })
})

const getAllPlans = catchAsync(async (req, res) => {
  const filterData = pick(req.query, ['airLinesId'])
  const peginationData = pick(req.query, ['limit', 'page'])
  const result = await PlaneService.getPlanesByAirlineId(
    filterData,
    peginationData,
  )
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Planes fetched successfully',
    meta: result.meta,
    data: result.data,
  })
})

const updatePlane = catchAsync(async (req, res) => {
  const { id } = req.params
  const planeData = req.body
  const result = await PlaneService.updatePlaneInfoIntoDB(id, planeData)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Plane updated successfully',
    data: result,
  })
})

const deletePlanInfo = catchAsync(async (req, res) => {
  const { id } = req.params
  const result = await PlaneService.deletePlaneInfoIntoDB(id)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Plane deleted successfully',
    data: result,
  })
})

export const PlaneController = {
  createPlane,
  getAllPlans,
  updatePlane,
  deletePlanInfo,
}
