/* eslint-disable @typescript-eslint/no-explicit-any */
import { PlaneDetails } from '@prisma/client'
import { prisma } from '../../shared/prisma'
import ApiError from '../../error/ApiError'
import httpStatus from 'http-status'
import peginationOption from '../../helper/peginationHelpers'

//create plane for airline
const createPlaneIntoDB = async (payload: PlaneDetails) => {
  const findPlane = await prisma.planeDetails.findUnique({
    where: {
      planeId: payload.planeId,
    },
  })

  if (findPlane) {
    throw new ApiError(httpStatus.FORBIDDEN, 'Plane already exists')
  }

  const findAirLines = await prisma.airLines.findUnique({
    where: {
      id: payload.airLinesId,
    },
  })

  if (!findAirLines) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Airline not found')
  }

  const result = await prisma.planeDetails.create({
    data: payload,
  })

  return result
}

//get all planes for specific airline
const getPlanesByAirlineId = async (params: any, options: any) => {
  const { limit, page, skip } = peginationOption(options)

  const findAirLines = await prisma.airLines.findUnique({
    where: {
      id: params.airLinesId,
    },
  })

  if (!findAirLines) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Airline not found')
  }

  const result = await prisma.planeDetails.findMany({
    where: {
      airLinesId: params.airLinesId,
    },
    take: limit,
    skip,
  })

  const totalRecords = await prisma.planeDetails.count({
    where: {
      airLinesId: params.airLinesId,
    },
  })

  return {
    meta: {
      limit,
      page,
      total: totalRecords,
    },
    data: result,
  }
}

//update plane info
const updatePlaneInfoIntoDB = async (
  id: string,
  payload: Partial<PlaneDetails>,
) => {
  const { planeName, planeId, capacity } = payload

  const findPlane = await prisma.planeDetails.findUnique({
    where: {
      id,
      isDeleted: false,
    },
  })

  if (!findPlane) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Plane not found')
  }

  const result = await prisma.planeDetails.update({
    where: {
      id,
    },
    data: {
      planeName,
      planeId,
      capacity,
    },
  })

  return result
}

//delete plane info
const deletePlaneInfoIntoDB = async (id: string) => {
  const findPlane = await prisma.planeDetails.findUnique({
    where: {
      id,
      isDeleted: false,
    },
  })

  if (!findPlane) {
    throw new ApiError(httpStatus.NOT_FOUND, 'Plane not found')
  }

  const result = await prisma.planeDetails.update({
    where: {
      id,
    },
    data: {
      isDeleted: true,
    },
  })

  return result
}

export const PlaneService = {
  createPlaneIntoDB,
  getPlanesByAirlineId,
  updatePlaneInfoIntoDB,
  deletePlaneInfoIntoDB,
}
