import catchAsync from '../../shared/catchAsync'
import { UserService } from './user.service'
import httpStatus from 'http-status'
import sendResponse from '../../shared/sendResponse'
import { IAuthUser } from '../../interface/common'

const createOwner = catchAsync(async (req, res) => {
  const result = await UserService.createOwnerIntoDB(req)
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Owner created successfully',
    data: result,
  })
})

const createBusCompanyEmployee = catchAsync(async (req, res) => {
  const { companyName } = req.user

  const result = await UserService.createBusCompanyEmployeeIntoDB(
    req.body,
    companyName,
  )
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Admin created successfully',
    data: result,
  })
})

//get spicific bus company owner
const getSpicificUserIntoDB = catchAsync(async (req, res) => {
  const { contactNumber } = req.user
  const result = await UserService.getSpicificUser(contactNumber)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'User fetched successfully',
    data: result,
  })
})

const getAllBusOwner = catchAsync(async (req, res) => {
  const result = await UserService.getAllBusOwner()
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'Bus owners are fetched successfully',
    data: result,
  })
})

const getAllPassenger = catchAsync(async (req, res) => {
  const result = await UserService.getAllPassenger()
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'All passengers are fetched successfully',
    data: result,
  })
})

//create bus counter employee
const createBusCounterEmployee = catchAsync(async (req, res) => {
  const result = await UserService.createBusCounterEmployeeIntoDB(req)
  sendResponse(res, {
    statusCode: httpStatus.CREATED,
    message: 'Bus counter employee created successfully',
    data: result,
  })
})

//get all bus counter employee
const getAllEmployeeForSpicificBusCompanyFromDB = catchAsync(
  async (req, res) => {
    const result = await UserService.getAllEmployeeForSpicificBusCompany(req)
    sendResponse(res, {
      statusCode: httpStatus.OK,
      message: 'Employee fetched successfully',
      data: result,
    })
  },
)

//me
const getMeFromDB = catchAsync(async (req, res) => {
  const result = await UserService.getMe(req)
  sendResponse(res, {
    statusCode: httpStatus.OK,
    message: 'User fetched successfully',
    data: result,
  })
})

const updateMyProfile = catchAsync(async (req, res) => {
  const user = req.user
  const result = await UserService.updateMyProfile(user as IAuthUser, req)
  sendResponse(res, {
    statusCode: 200,
    message: 'My profile updated',
    data: result,
  })
})

export const UserController = {
  createBusCompanyEmployee,
  createOwner,
  getSpicificUserIntoDB,
  getAllBusOwner,
  createBusCounterEmployee,
  getAllPassenger,
  getAllEmployeeForSpicificBusCompanyFromDB,
  getMeFromDB,
  updateMyProfile
}
