import { Router } from 'express'
import { UserController } from './user.controller'
import auth from '../../middleware/auth'
import { UserRoles } from '@prisma/client'
import { UserValidation } from './user.validation'
import { multerUploads } from '../../config/multer.config'

const router = Router()

router.get(
  '/get-all-employee',
  auth(UserRoles.OWNER),
  UserController.getAllEmployeeForSpicificBusCompanyFromDB,
)

router.get('/', auth(UserRoles.OWNER), UserController.getSpicificUserIntoDB)
router.get(
  '/get-all-bus-comany-owner',
  auth(UserRoles.SUPER_ADMIN),
  UserController.getAllBusOwner,
)
router.get(
  '/get-all-passenger',
  auth(UserRoles.SUPER_ADMIN),
  UserController.getAllPassenger,
)

router.get(
  '/me',
  auth(UserRoles.SUPER_ADMIN, UserRoles.OWNER, UserRoles.PASSENGER),
  UserController.getMeFromDB,
)

router.post(
  '/create-owner',
  // auth(UserRoles.SUPER_ADMIN),
  multerUploads.single('image'),
  (req, res, next) => {
    req.body = UserValidation.CreateOwnerSchemaValidation.parse(
      JSON.parse(req.body.data),
    )
    return UserController.createOwner(req, res, next)
  },
)

router.post(
  '/create-bus-couter-employee',
  auth(UserRoles.OWNER),
  multerUploads.single('image'),
  (req, res, next) => {
    req.body = UserValidation.CreateBusCounterSchemaValidation.parse(
      JSON.parse(req.body.data),
    )
    return UserController.createBusCounterEmployee(req, res, next)
  },
)

router.post(
  '/admin/create-employee',
  auth(UserRoles.OWNER),
  UserController.createBusCompanyEmployee,
)

router.patch(
  '/update-my-profile',
  auth(UserRoles.SUPER_ADMIN, UserRoles.OWNER, UserRoles.PASSENGER),
  multerUploads.single('image'),
  (req, res, next) => {
    req.body = JSON.parse(req.body.data)
    return UserController.updateMyProfile(req, res, next)
  },
)

export const UserRouter = router
