import { z } from 'zod'

const CreateOwnerSchemaValidation = z.object({
  password: z.string({
    required_error: 'Password is required',
  }),
  companyOwner: z.object({
    fullName: z.string({
      required_error: 'Full name is required',
    }),
    email: z
      .string({
        required_error: 'Email is required',
      })
      .email(),
    contactNumber: z.string({
      required_error: 'Contact number is required',
    }),
    emergencyContactNumber: z.string({
      required_error: 'Emergency contact number is required',
    }),
    presentAddress: z.string({
      required_error: 'Present address is required',
    }),
    permanentAddress: z.string({
      required_error: 'Permanent address is required',
    }),
    gender: z.enum(['MALE', 'FEMALE'], {
      required_error: 'Gender is required',
    }),
    dateOfBirth: z.string({
      required_error: 'Date of birth is required',
    }),
    transportType: z.enum(['BUS', 'AIRLINECS'], {
      required_error: 'Transport type is required',
    }),
    companyName: z.string({
      required_error: 'Company name is required',
    }),
    nidCardNumber: z.string({
      required_error: 'NID card number is required',
    }),
  }),
})

const CreateBusCounterSchemaValidation = z.object({
  password: z.string({
    required_error: 'Password is required',
  }),
  counterEmployee: z.object({
    counterId: z.string({
      required_error: 'Counter ID is required',
    }),
    name: z.string({
      required_error: 'Full name is required',
    }),
    email: z
      .string({
        required_error: 'Email is required',
      })
      .email(),
    contactNumber: z.string({
      required_error: 'Contact number is required',
    }),
    emergencyContactNumber: z.string({
      required_error: 'Emergency contact number is required',
    }),
    presentAddress: z.string({
      required_error: 'Present address is required',
    }),
    permanentAddress: z.string({
      required_error: 'Permanent address is required',
    }),
    gender: z.enum(['MALE', 'FEMALE'], {
      required_error: 'Gender is required',
    }),
    dateOfBirth: z.string({
      required_error: 'Date of birth is required',
    }),
    nidCardNumber: z.string({
      required_error: 'NID card number is required',
    }),
  }),
})

export const UserValidation = {
  CreateOwnerSchemaValidation,
  CreateBusCounterSchemaValidation,
}
