/* eslint-disable no-console */
/* eslint-disable no-unused-vars */
/* eslint-disable @typescript-eslint/no-unused-vars */
import { Server } from 'http'
import app from './app'
import config from './app/config'
import createSuperAdmin from './app/DB'
import { prisma } from './app/shared/prisma'
// Assuming you have a prisma client file

async function main() {
  try {
    // First ensure database connection
    await prisma.$connect()
    console.log('Database connection established')

    // Start the server
    const server: Server = app.listen(config.port, () => {
      console.log(`Server is running on port ${config.port}`)
    })

    // Handle server shutdown gracefully
    server.on('error', error => {
      console.error('Server error:', error)
    })

    // Create super admin after server starts
    try {
      await createSuperAdmin()
      console.log('Super admin creation process completed')
    } catch (adminError) {
      console.error('Error creating super admin:', adminError)
      // Continue running the server even if super admin creation fails
    }

    // Handle graceful shutdown
    process.on('SIGTERM', async () => {
      console.log('SIGTERM received. Shutting down gracefully...')
      await prisma.$disconnect()
      server.close(() => {
        console.log('Server closed')
        process.exit(0)
      })
    })
  } catch (error) {
    console.error('Failed to start server:', error)
    await prisma.$disconnect()
    process.exit(1)
  }
}

// Handle uncaught errors
process.on('unhandledRejection', error => {
  console.error('Unhandled rejection:', error)
})

main().catch(async e => {
  console.error(e)
  await prisma.$disconnect()
  process.exit(1)
})
